/*
** Module   : WebHandler.java
** Abstract : starts ChuiWebClient and redirect to the embedded server URI.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**         Golden Code Development Corporation
**                 CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------Description--------------------------
** 001 MAG 20131113 Created initial version
*/

package com.goldencode.p2j.main;

import java.io.*;
import java.util.logging.*;

import javax.servlet.*;
import javax.servlet.http.*;

import org.eclipse.jetty.server.handler.*;
import org.eclipse.jetty.server.*;

import com.goldencode.p2j.util.*;

/**
 * Starts a web client and redirect the request to the embedded server URI.
 * 
 */
public class WebHandler
extends AbstractHandler
{
   /** Logger. */
   private static final Logger LOG = LogHelper.getLogger(WebHandler.class.getName());
   
   /** The root portion of the target request name (part of the URL). */
   private String targetRoot = null;
        
   /**
    * Constructor.
    *
    * @param    targetRoot
    *           Prefix for all URLs relating to this URI.
    */
   public WebHandler(String targetRoot)
   {     
      if (!targetRoot.startsWith("/"))
      {
         targetRoot = "/" + targetRoot;
      }
      
      if (targetRoot.endsWith("/"))
      {
         targetRoot = targetRoot.substring(0, targetRoot.length() - 1);
      }
      
      this.targetRoot = targetRoot;
   }
   
   /**
    * Spawn web client and redirect the request to the embedded server.
    *    
    * @param    target 
    *           The target of the request - either a URI or a name.
    * @param    base
    *           The base request.
    * @param    request
    *           The object or a wrapper of the request.
    * @param    response 
    *           The object or a wrapper of the response. 
    */
   public void handle(String              target, 
                      Request             base,
                      HttpServletRequest  request,
                      HttpServletResponse response)
   throws IOException, 
          ServletException
   {         
      if (!base.isHandled() && target.equals(targetRoot))
      {
         String uri = SpawnerImpl.getInstance().spawn();
         if (uri != null)
         {
            LOG.logp(Level.INFO,
                     "WebHandler.handle",
                     "",
                     LogHelper.generate("Redirect to " + uri));            
            response.sendRedirect(uri);
         }
         else
         {
            PrintWriter writer = response.getWriter();
            writer.write("<html><body><h1 style=\"color:red\">" +
            		"Cannot start the embedded server.</h1></body></html>");
            writer.close();
         }
         
         base.setHandled(true);
      }      
   }   
}
